@@ -424,7 +424,7 @@ class CreateBPBrandResponse(AbstractModel):
         r"""
         :param _CompanyId: 企业id
         :type CompanyId: int
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._CompanyId = None
@@ -492,7 +492,7 @@ class CreateBPFakeAPPListResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._RequestId = None
@@ -634,11 +634,22 @@ class CreateBPFakeAPPResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _FakeAPPId: FakeAPPId
+        :type FakeAPPId: int
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
+        self._FakeAPPId = None
         self._RequestId = None
 
+    @property
+    def FakeAPPId(self):
+        return self._FakeAPPId
+
+    @FakeAPPId.setter
+    def FakeAPPId(self, FakeAPPId):
+        self._FakeAPPId = FakeAPPId
+
     @property
     def RequestId(self):
         return self._RequestId
@@ -649,6 +660,7 @@ class CreateBPFakeAPPResponse(AbstractModel):
 
 
     def _deserialize(self, params):
+        self._FakeAPPId = params.get("FakeAPPId")
         self._RequestId = params.get("RequestId")
 
 
@@ -728,11 +740,22 @@ class CreateBPFakeURLResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _FakeURLId: FakeURLId
+        :type FakeURLId: int
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
+        self._FakeURLId = None
         self._RequestId = None
 
+    @property
+    def FakeURLId(self):
+        return self._FakeURLId
+
+    @FakeURLId.setter
+    def FakeURLId(self, FakeURLId):
+        self._FakeURLId = FakeURLId
+
     @property
     def RequestId(self):
         return self._RequestId
@@ -743,6 +766,7 @@ class CreateBPFakeURLResponse(AbstractModel):
 
 
     def _deserialize(self, params):
+        self._FakeURLId = params.get("FakeURLId")
         self._RequestId = params.get("RequestId")
 
 
@@ -786,7 +810,7 @@ class CreateBPFakeURLsResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._RequestId = None
@@ -880,7 +904,7 @@ class CreateBPWhiteListResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._RequestId = None
@@ -938,7 +962,7 @@ class DeleteBPWhiteListResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._RequestId = None
@@ -973,7 +997,7 @@ class DescribeBPBrandsResponse(AbstractModel):
         :type Brands: list of BrandData
         :param _NoticeStatus: 品牌审核通知栏状态：0 不显示 1 显示
         :type NoticeStatus: int
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._Brands = None
@@ -1089,7 +1113,7 @@ class DescribeBPFakeAPPListResponse(AbstractModel):
         :type FakeAPPList: list of FakeAPPData
         :param _TotalCount: 仿冒应用总数
         :type TotalCount: int
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._FakeAPPList = None
@@ -1205,7 +1229,7 @@ class DescribeBPFakeURLsResponse(AbstractModel):
         :type FakeURLs: list of FakeURLData
         :param _TotalCount: 仿冒网址总数
         :type TotalCount: int
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._FakeURLs = None
@@ -1321,7 +1345,7 @@ class DescribeBPWhiteListsResponse(AbstractModel):
         :type WhiteLists: list of WhiteListData
         :param _TotalCount: 白名单总数
         :type TotalCount: int
-        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self._WhiteLists = None
@@ -1669,6 +1693,9 @@ class FakeURLData(AbstractModel):
         :param _AuditStatus: 审核状态：0-未审核 1-审核中 2-审核成功 3-审核失败
 注意：此字段可能返回 null，表示取不到有效值。
         :type AuditStatus: int
+        :param _OfflineTime: 下线时间
+注意：此字段可能返回 null，表示取不到有效值。
+        :type OfflineTime: str
         """
         self._FakeURLId = None
         self._BrandName = None
@@ -1693,6 +1720,7 @@ class FakeURLData(AbstractModel):
         self._Snapshot = None
         self._AccountStatus = None
         self._AuditStatus = None
+        self._OfflineTime = None
 
     @property
     def FakeURLId(self):
@@ -1878,6 +1906,14 @@ class FakeURLData(AbstractModel):
     def AuditStatus(self, AuditStatus):
         self._AuditStatus = AuditStatus
 
+    @property
+    def OfflineTime(self):
+        return self._OfflineTime
+
+    @OfflineTime.setter
+    def OfflineTime(self, OfflineTime):
+        self._OfflineTime = OfflineTime
+
 
     def _deserialize(self, params):
         self._FakeURLId = params.get("FakeURLId")
@@ -1903,6 +1939,7 @@ class FakeURLData(AbstractModel):
         self._Snapshot = params.get("Snapshot")
         self._AccountStatus = params.get("AccountStatus")
         self._AuditStatus = params.get("AuditStatus")
+        self._OfflineTime = params.get("OfflineTime")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
